﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace WmsTest
{
    /// <summary>
    /// Interaction logic for MyTest.xaml
    /// </summary>
    public partial class MyTest : Window
    {
        public MyTest()
        {
            InitializeComponent();
        }

        private void MyTest_OnLoaded(object sender, RoutedEventArgs e)
        {
            //We need to set the map unit to meter because we are using Google Map Spherical Mercator projection.
            winformsMap1.MapUnit = GeographyUnit.Meter;

            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.FromArgb(255, 198, 255, 255));

            //Sets Google Map as the background map.
            GoogleMapsOverlay googleMapsOverlay = new GoogleMapsOverlay(){MapType = GoogleMapsMapType.Satellite};
            winformsMap1.Overlays.Add(googleMapsOverlay);

            //Projection to go from Geodetic (Longitude/Latitude) to Google Map projection (Spherical Mercator).
            Proj4Projection proj4 = new Proj4Projection();
            proj4.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326); //Geodetic projection (Longitude/Latitude).
            proj4.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();

            ShapeFileFeatureLayer schoolShapeLayer = new ShapeFileFeatureLayer(@"ShpFiles\austinschools.shp");
            schoolShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Circle, GeoColor.StandardColors.Red, GeoColor.StandardColors.Black, 9);
            schoolShapeLayer.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.CreateMaskTextStyle("NAME", new GeoFont("Arial", 10, DrawingFontStyles.Bold),
            new GeoSolidBrush(GeoColor.StandardColors.Black), new AreaStyle(new GeoSolidBrush(GeoColor.StandardColors.LightGoldenrodYellow)), 13, 0);
            schoolShapeLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            //Sets the projection to the shapefile layer.
            schoolShapeLayer.FeatureSource.Projection = proj4;

            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add("SchoolShapeLayer", schoolShapeLayer);

            winformsMap1.Overlays.Add(staticOverlay);

            //Sets the extent of the map as the bounding box of the shapefile layer as projected (Google Map Spherical Mercator).
            schoolShapeLayer.Open();
            winformsMap1.CurrentExtent = schoolShapeLayer.GetBoundingBox();
            schoolShapeLayer.Close();

            winformsMap1.Refresh();
        }
    }
}
