﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WpfDesktopEdition;

namespace WmsTest
{
    /// <summary>
    /// Interaction logic for WmsImage.xaml
    /// </summary>
    public partial class WmsImage : UserControl
    {
        public WmsImage()
        {
            InitializeComponent();
        }

        private void WmsImage_OnLoaded(object sender, RoutedEventArgs e)
        {
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;
            wpfMap1.CurrentExtent = new RectangleShape(-143.4, 109.3, 116.7, -76.3);

            UseOverlay();
        }


        private void UseLayer()
        {
            wpfMap1.Overlays.Clear();

            WmsRasterLayer wmsImageLayer = new WmsRasterLayer(new Uri("http://wmssamples.thinkgeo.com/WmsServer.aspx"));
            wmsImageLayer.UpperThreshold = double.MaxValue;
            wmsImageLayer.LowerThreshold = 0;

            wmsImageLayer.Open();
            foreach (string layerName in wmsImageLayer.GetServerLayerNames())
            {
                wmsImageLayer.ActiveLayerNames.Add(layerName);
            }
            //// this parameter is just optional.   
            //wmsImageLayer.Exceptions = "application/vnd.ogc.se_xml";

            LayerOverlay staticOverlay = new LayerOverlay();
            staticOverlay.Layers.Add("wmsImageLayer", wmsImageLayer);
            wpfMap1.Overlays.Add(staticOverlay);
            wmsImageLayer.Close();

            wpfMap1.Refresh();
        }

        private void UseOverlay()
        {
            wpfMap1.Overlays.Clear();

            var wmsOverlay = new WmsOverlay();
            wmsOverlay.ServerUris.Add(new Uri("http://wmssamples.thinkgeo.com/WmsServer.aspx"));
            wmsOverlay.Parameters.Add("LAYERS", "Countries02");
            wmsOverlay.Parameters.Add("STYLES", "SIMPLE");
            wpfMap1.Overlays.Add(wmsOverlay);

            wpfMap1.Refresh();
        }


        private void test()
        {
            // Set the Map Unit. The reason for setting it to DecimalDegrees is that is what the shapefile’s unit of measure is inherently in.
            wpfMap1.MapUnit = GeographyUnit.DecimalDegree;

            // We create a new Layer and pass the path to a Shapefile into its constructor. 
            ShapeFileFeatureLayer worldLayer = new ShapeFileFeatureLayer(@"E:\Program Files (x86)\ThinkGeo\Map Suite Wpf Desktop Full Edition 7.0\Samples\CSharp Samples\SampleData\Data\Countries02.shp");

            // Set the worldLayer with a preset Style, as AreaStyles.Country1 has YellowGreen background and black border, our worldLayer will have the same render style.  
            worldLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.Country1;

            // This setting will apply from ZoonLevel01 to ZoomLevel20, that means we can see the world the same style with ZoomLevel01 all the time no matter how far we zoom out/in. 
            worldLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            // Create a new Layer Overlay to hold the layer we just created
            LayerOverlay layerOverlay = new LayerOverlay();

            // Add the shapefile layer to the layer overlay
            layerOverlay.Layers.Add(worldLayer);

            // We need to add the layer overlay to Map.
            wpfMap1.Overlays.Add(layerOverlay);

            // Set a proper extent for the Map.  
            wpfMap1.CurrentExtent = new RectangleShape(0, 78, 30, 26);

            // We now need to call the Refresh() method of the Map control so that the Map can redraw based on the data that has been provided.
            wpfMap1.Refresh();
        }



        private void WmsOverlayRadioButton_OnChecked(object sender, RoutedEventArgs e)
        {
            UseOverlay();
        }

        private void WmsRasterLayerRadioButton_OnChecked(object sender, RoutedEventArgs e)
        {
            UseLayer();
        }
    }
}
